@@ -194,6 +194,16 @@ if (process.env.NODE_RED_ENABLE_PROJECTS) {
     settings.editorTheme.projects.enabled = !/^false$/i.test(process.env.NODE_RED_ENABLE_PROJECTS);
 }
 
+
+var defaultServerSettings = {
+    "x-powered-by": false
+}
+var serverSettings = Object.assign({},defaultServerSettings,settings.httpServerOptions||{});
+for (var eOption in serverSettings) {
+    app.set(eOption, serverSettings[eOption]);
+}
+
+
 // Delay logging of (translated) messages until the RED object has been initialized
 var delayedLogItems = [];
 
@@ -263,7 +273,6 @@ httpsPromise.then(function(startupHttps) {
         settings.httpAdminRoot = false;
         settings.httpNodeRoot = false;
     } else {
-        settings.httpRoot = settings.httpRoot||"/";
         settings.disableEditor = settings.disableEditor||false;
     }
 
